@@ -40,12 +40,18 @@ def job_commands():
 @click.option('-r', '--run', help='Create and run the job.', is_flag=True)
 @click.option('-w', '--wait', help='Wait for the job to finish.', is_flag=True)
 @click.option('-cit', '--instance-type',
-              help="Cluster instance type, options are: -s (small - default), -m (medium), -l (large).",
-              type=click.Choice(['s', 'm', 'l']), default='s')
+              help="Cluster instance type, options are: -s (small - default), -m (medium), -l (large) -gpu_s(small gpu), -gpu_m(medium gpu) -gpu_l(large gpu).\n"
+                   "When running a gpu job using your own cluster (adding -cid option with your cluster id), you'll be able to run gpu jobs without extra configuration.\n"
+                   "When running a gpu job using the default disco cloud, contact disco to enable your account to run these type of jobs.\n",
+              type=click.Choice(['s', 'm', 'l', 'gpu_s', 'gpu_m', 'gpu_l']), default='s')
 @click.option('-cid', '--cluster-id', help="Cluster id to run the job on. "
                                            "You can use the ‘cluster list’ command to view your clusters. "
                                            "In case no cluster-id specified, Dis.co runs the job "
                                            "on the default Dis.co cluster.")
+@click.option('-cic', '--instance-cost', help="The cost type of an instance, available only on clouds.\n"
+                                              "1.'guaranteed': Aws - On Demand, Gcp - VM, Azure - Virtual Machines, Packet - On Demand.\n"
+                                              "2.'lowCost': only supported on aws cloud, uses aws spot instances and reduces costs.",
+                                              type=click.Choice(['guaranteed', 'lowCost']))
 @click.option('-rep', '--repository-id', help='ID of the repository in which the script file resides.')
 @click.option('-f', '--file-path', 'script_file_path_in_repo', help='Path in the Git repository to the script file.')
 @click.option('-did', '--docker-image-id', help='The id of the docker image to run the job in')  # pylint: disable=all
@@ -55,7 +61,7 @@ def job_commands():
 @click.option('--dont-generate-req-file', hidden=True, is_flag=True)
 @common_options
 @pass_state
-def create_job(state, script, inputs, raw_bucket_paths, constants, name, run, wait, instance_type, cluster_id,
+def create_job(state, script, inputs, raw_bucket_paths, constants, name, run, wait, instance_type, cluster_id, instance_cost,
                # pylint: disable=redefined-builtin
                repository_id, script_file_path_in_repo, docker_image_id, timeout, debug_mode, dont_generate_req_file):
     """
@@ -119,7 +125,7 @@ def create_job(state, script, inputs, raw_bucket_paths, constants, name, run, wa
         script_file_id = None if script is None else upload_job_script_file(script, cluster, show_progress_bar)
         created_job = Job.create(script_file_id=script_file_id, input_file_ids=input_file_ids,
                                  constants_file_ids=const_file_ids, job_name=name, cluster_instance_type=instance_type,
-                                 cluster_id=cluster_id, script_repo_id=repository_id,
+                                 cluster_id=cluster_id, instance_cost=instance_cost, script_repo_id=repository_id,
                                  script_file_path_in_repo=script_file_path_in_repo, auto_start=run,
                                  upload_requirements_file=not dont_generate_req_file, docker_image_id=docker_image_id)
 
@@ -143,6 +149,9 @@ def create_job(state, script, inputs, raw_bucket_paths, constants, name, run, wa
             if match is not None:
                 error_message(match.string + '\nTry `cluster list` and `docker list` commands.')
                 return
+            if msg.find('Operation not supported: lowCost instance cost type on') >= 0:
+                error_message(msg)
+                return
     except DiscoException as ex:
         if debug_mode:
             print(ex)
