@@ -26,3 +26,22 @@ class Cluster(BaseController):
             return []
         return [ClusterDetails(cluster, res['fetchProfile']['defaultClusterId'] == cluster['id'])
                 for cluster in res['fetchProfile']['clusters']]
+
+    @classmethod
+    def fetch_and_validate_by_id(cls, cluster_id):
+        """
+        Validate that the cluster_id belongs to the user
+
+        Args:
+            cluster_id (str):
+
+        Returns:
+            False if invalid or ClusterDetails if valid
+        """
+        user_clusters = cls.list_clusters()
+        cluster = next((cluster for cluster in user_clusters if cluster.id == cluster_id), None)
+
+        if not cluster:
+            return False
+
+        return cluster
