@@ -17,7 +17,6 @@ from .core import constants, exceptions, \
 from .task import TaskResult
 from .base_controller import BaseController
 
-
 class Job(BaseController):
     """A job that runs on DISCO machines.
 
@@ -103,6 +102,7 @@ class Job(BaseController):
             job_name=None,
             cluster_instance_type='s',
             cluster_id=None,
+            instance_cost=None,
             script_repo_id=None,
             script_file_path_in_repo=None,
             auto_start=False,
@@ -119,9 +119,11 @@ class Job(BaseController):
                 to use a random string.
             cluster_instance_type: Is the size of instance used. Choose 'm'
                 for a medium instance and 'l' for a large instance.
+                Use gpu_s, gpu_m, gpu_l for gpu jobs (read more about gpu on disco job create -h).
                 The default is 's' for small.
             cluster_id: Specifies the ID of the cluster on which to run the
                 job. Leave as `None` to run on DISCO's cluster.
+            instace_cost: instance cost type : guaranteed or lowCost. default is None.
             script_repo_id (str): The id of the Git repository in which the script file to run is.
                 (Alternative to script_file_id).
             script_file_path_in_repo (str): The path in the Git repository to the script file.
@@ -166,6 +168,9 @@ class Job(BaseController):
             job_meta['scriptRepoId'] = script_repo_id
             job_meta['scriptFilePath'] = script_file_path_in_repo
 
+        if instance_cost is not None:
+            job_meta['instanceCostType'] = instance_cost
+
         job_options = {
             'executeOnSubmit': auto_start
         }
