@@ -123,7 +123,7 @@ class TestJobCommands(BaseTest):
                 assert output_message_includes(result, 'Created job with id job_id')
                 job_create_mock.assert_called_with(script_file_id='file_id', input_file_ids=['file_id'],
                                                    constants_file_ids=[], job_name='job_name', cluster_instance_type='s',
-                                                   cluster_id=None, script_repo_id=None, script_file_path_in_repo=None,
+                                                   cluster_id=None, instance_cost=None, script_repo_id=None, script_file_path_in_repo=None,
                                                    auto_start=False, upload_requirements_file=True, docker_image_id=None
                                                    )
 
@@ -211,7 +211,8 @@ class TestJobCommands(BaseTest):
                                                    constants_file_ids=[],
                                                    job_name=job_name, docker_image_id=None, script_repo_id=None,
                                                    script_file_path_in_repo=None,
-                                                   cluster_instance_type='s', cluster_id=cluster_id, auto_start=False,
+                                                   cluster_instance_type='s', cluster_id=cluster_id, 
+                                                   instance_cost=None, auto_start=False,
                                                    upload_requirements_file=True)
 
     @patch('disco.gql.authentication.Authentication.is_logged_in')
@@ -429,7 +430,8 @@ class TestJobCommands(BaseTest):
                                                    constants_file_ids=[],
                                                    job_name=job_name, docker_image_id=None, script_repo_id=None,
                                                    script_file_path_in_repo=None,
-                                                   cluster_instance_type='s', cluster_id=cluster_id, auto_start=False,
+                                                   cluster_instance_type='s', cluster_id=cluster_id, 
+                                                   instance_cost=None, auto_start=False,
                                                    upload_requirements_file=True)
 
     @patch('disco.gql.authentication.Authentication.is_logged_in')
@@ -450,7 +452,7 @@ class TestJobCommands(BaseTest):
                 assert result.exit_code == 0
                 assert output_message_includes(result, 'Created job with id job_id')
                 job_create_mock.assert_called_with(script_file_id='file_id', input_file_ids=[], constants_file_ids=[],
-                                                   job_name='job_name', cluster_instance_type='s', cluster_id=None,
+                                                   job_name='job_name', cluster_instance_type='s', cluster_id=None, instance_cost=None,
                                                    script_repo_id=None, script_file_path_in_repo=None, auto_start=False,
                                                    upload_requirements_file=True, docker_image_id=None)
 
@@ -475,7 +477,7 @@ class TestJobCommands(BaseTest):
                 assert result.exit_code == 0
                 assert output_message_includes(result, 'Created job with id job_id')
                 job_create_mock.assert_called_with(script_file_id='file_id', input_file_ids=[], constants_file_ids=[],
-                                                   job_name='job_name', cluster_instance_type='s', cluster_id=None,
+                                                   job_name='job_name', cluster_instance_type='s', cluster_id=None, instance_cost=None, 
                                                    script_repo_id=None, script_file_path_in_repo=None, auto_start=False,
                                                    upload_requirements_file=True, docker_image_id=None)
 
@@ -507,8 +509,8 @@ class TestJobCommands(BaseTest):
                 assert output_message_includes(result, 'Created job with id job_id')
                 job_create_mock.assert_called_with(script_file_id='file_id', input_file_ids=['file_id'],
                                                    constants_file_ids=[], job_name='job_name',
-                                                   cluster_instance_type='s', cluster_id=None, script_repo_id=None,
-                                                   script_file_path_in_repo=None, auto_start=False,
+                                                   cluster_instance_type='s', cluster_id=None, instance_cost=None, 
+                                                   script_repo_id=None, script_file_path_in_repo=None, auto_start=False,
                                                    upload_requirements_file=False, docker_image_id=None)
 
     @patch('disco.gql.authentication.Authentication.is_logged_in')
@@ -535,8 +537,8 @@ class TestJobCommands(BaseTest):
                 assert output_message_includes(result, 'Created job with id job_id')
                 job_create_mock.assert_called_with(script_file_id='file_id', input_file_ids=[],
                                                    constants_file_ids=['file_id'], job_name='job_name',
-                                                   cluster_instance_type='s', cluster_id=None, script_repo_id=None,
-                                                   script_file_path_in_repo=None, auto_start=False,
+                                                   cluster_instance_type='s', cluster_id=None, instance_cost=None, 
+                                                   script_repo_id=None, script_file_path_in_repo=None, auto_start=False,
                                                    upload_requirements_file=True, docker_image_id=None)
 
     @patch('disco.gql.authentication.Authentication.is_logged_in')
@@ -565,8 +567,8 @@ class TestJobCommands(BaseTest):
                 assert output_message_includes(result, 'Created job with id job_id')
                 job_create_mock.assert_called_with(script_file_id='file_id', input_file_ids=['file_id', 'file_id'],
                                                    constants_file_ids=['file_id', 'file_id'], job_name='job_name',
-                                                   cluster_instance_type='s', cluster_id=None, script_repo_id=None,
-                                                   script_file_path_in_repo=None, auto_start=False,
+                                                   cluster_instance_type='s', cluster_id=None, instance_cost=None, 
+                                                   script_repo_id=None, script_file_path_in_repo=None, auto_start=False,
                                                    upload_requirements_file=True, docker_image_id=None)
 
     @patch('disco.gql.authentication.Authentication.is_logged_in')
@@ -614,7 +616,7 @@ class TestJobCommands(BaseTest):
                                                    input_file_ids=[input_file_id1, input_file_id2],
                                                    constants_file_ids=[], job_name=job_name,
                                                    cluster_instance_type='s', cluster_id=cluster_id,
-                                                   script_repo_id=None,
+                                                   instance_cost=None, script_repo_id=None,
                                                    script_file_path_in_repo=None, auto_start=False,
                                                    upload_requirements_file=True, docker_image_id=None)
 
@@ -662,8 +664,8 @@ class TestJobCommands(BaseTest):
                 assert output_message_includes(result, 'Created job with id job_id')
                 job_create_mock.assert_called_with(script_file_id='file_id', input_file_ids=['file_id', 'file_id'],
                                                    constants_file_ids=[], job_name='job_name',
-                                                   cluster_instance_type='s', cluster_id=None, script_repo_id=None,
-                                                   script_file_path_in_repo=None, auto_start= False,
+                                                   cluster_instance_type='s', cluster_id=None, instance_cost=None, 
+                                                   script_repo_id=None, script_file_path_in_repo=None, auto_start= False,
                                                    upload_requirements_file=True, docker_image_id=None)
 
     @patch('disco.gql.authentication.Authentication.is_logged_in')
@@ -706,8 +708,8 @@ class TestJobCommands(BaseTest):
                 job_create_mock.assert_called_with(script_file_id=script_file_id,
                                                    input_file_ids=[input_file_id1, input_file_id2],
                                                    constants_file_ids=[], job_name='job_name',
-                                                   cluster_instance_type='s', cluster_id=None, script_repo_id=None,
-                                                   script_file_path_in_repo=None, auto_start=False,
+                                                   cluster_instance_type='s', cluster_id=None, instance_cost=None, 
+                                                   script_repo_id=None, script_file_path_in_repo=None, auto_start=False,
                                                    upload_requirements_file=True, docker_image_id=None)
 
                 asset_upload_mock.assert_has_calls([
@@ -882,8 +884,8 @@ class TestJobCommands(BaseTest):
             job_create_mock.assert_called_with(script_file_id=script_file_id,
                                                input_file_ids=[input_file_id1, input_file_id2],
                                                constants_file_ids=[constant_file_id], job_name='job_name',
-                                               cluster_instance_type='s', cluster_id=None, script_repo_id=None,
-                                               script_file_path_in_repo=None, auto_start=False,
+                                               cluster_instance_type='s', cluster_id=None, instance_cost=None, 
+                                               script_repo_id=None, script_file_path_in_repo=None, auto_start=False,
                                                upload_requirements_file=True, docker_image_id=None)
 
             asset_upload_mock.assert_has_calls([
@@ -926,7 +928,7 @@ class TestJobCommands(BaseTest):
             assert output_message_includes(result, f'Created job with id {job_id}')
             job_create_mock.assert_called_with(script_file_id=None, input_file_ids=[input_file_id],
                                                constants_file_ids=[], job_name=job_name, cluster_instance_type='s',
-                                               cluster_id=None, script_repo_id=repository_id,
+                                               cluster_id=None, instance_cost=None, script_repo_id=repository_id,
                                                script_file_path_in_repo=file_path, auto_start=False,
                                                upload_requirements_file=True, docker_image_id=None)
 
@@ -1044,7 +1046,7 @@ class TestJobCommands(BaseTest):
             assert output_message_includes(result, f'Created job with id {job_id}')
             job_create_mock.assert_called_with(script_file_id=None, input_file_ids=[input_file_id],
                                                constants_file_ids=[], job_name=job_name, cluster_instance_type='s',
-                                               cluster_id=None, script_repo_id=repository_id,
+                                               cluster_id=None, instance_cost=None, script_repo_id=repository_id,
                                                script_file_path_in_repo=file_path, auto_start=False,
                                                upload_requirements_file=True, docker_image_id=docker_image_id)
 
@@ -1072,6 +1074,157 @@ class TestJobCommands(BaseTest):
                 assert result.exit_code == 0
                 wait_for_finish_mock.assert_called_with(timeout=1000)
 
+    @patch('disco.gql.authentication.Authentication.is_logged_in')
+    @patch('disco.Job.create')
+    @patch('pathlib.Path.exists')
+    @patch('pathlib.Path.is_dir')
+    @patch('disco.asset.Asset.upload')
+    def test_create_job_with_low_cost_instance(self, asset_upload_mock, path_is_dir_mock,
+                                               path_exists_mock, job_create_mock, is_logged_in_mock):
+        """
+        Created a successful job using lowCost instance-cost for a aws cluster
+        """
+        is_logged_in_mock.return_value = True
+        path_exists_mock.return_value = True
+        path_is_dir_mock.return_value = False
+        job_create_mock.return_value = Job("job_id")
+        asset_upload_mock.return_value = 'file_id'
+        runner = CliRunner()
+        with runner.isolated_filesystem():
+            with open('script_file.py', 'w') as f:
+                f.write("print('hi!')")
+                result = runner.invoke(cli, "job create -n job_name -s script_file.py --instance-cost lowCost --run")
+                assert result.exit_code == 0
+                assert output_message_includes(result, 'Created job with id job_id')
+                job_create_mock.assert_called_with(script_file_id='file_id', input_file_ids=[],
+                                                   constants_file_ids=[], job_name='job_name',
+                                                   cluster_instance_type='s', cluster_id=None, instance_cost='lowCost' ,
+                                                   script_repo_id=None, script_file_path_in_repo=None, auto_start= True,
+                                                   upload_requirements_file=True, docker_image_id=None)
+
+    @patch('disco.gql.authentication.Authentication.is_logged_in')
+    @patch('disco.Job.create')
+    @patch('pathlib.Path.exists')
+    @patch('pathlib.Path.is_dir')
+    @patch('disco.asset.Asset.upload')
+    def test_create_job_with_low_cost_instance_on_non_supported_cluster(self, asset_upload_mock, path_is_dir_mock,
+                                                                        path_exists_mock, job_create_mock, is_logged_in_mock):
+        """
+        Failure to run a job using lowCost instance-cost for a non supported cluster (since this option only supported on aws clouds)
+        """
+        is_logged_in_mock.return_value = True
+        path_exists_mock.return_value = True
+        path_is_dir_mock.return_value = False
+        job_create_mock.return_value = Job("job_id")
+        asset_upload_mock.return_value = 'file_id'
+        runner = CliRunner()
+        with runner.isolated_filesystem():
+            with open('script_file.py', 'w') as f:
+                f.write("print('hi!')")
+                result = runner.invoke(cli, "job create -n job_name -s script_file.py -cic non-existing-cost --run")
+                
+                assert 'Error: Invalid value for "-cic" / "--instance-cost": invalid choice: non-existing-cost. (choose from guaranteed, lowCost)' in str(result.output)
+                job_create_mock.assert_not_called()
+
+    @patch('disco.gql.authentication.Authentication.is_logged_in')
+    @patch('disco.Job.create')
+    @patch('pathlib.Path.exists')
+    @patch('pathlib.Path.is_dir')
+    @patch('disco.asset.Asset.upload')
+    def test_create_instance_type_s_job(self, asset_upload_mock, path_is_dir_mock,
+                                   path_exists_mock, job_create_mock, is_logged_in_mock):
+        """
+        Successful path for creating a job using cluster instance type s
+        """
+        self._create_instance_type_job(asset_upload_mock, path_is_dir_mock,
+                                   path_exists_mock, job_create_mock, is_logged_in_mock, 's')
+
+    @patch('disco.gql.authentication.Authentication.is_logged_in')
+    @patch('disco.Job.create')
+    @patch('pathlib.Path.exists')
+    @patch('pathlib.Path.is_dir')
+    @patch('disco.asset.Asset.upload')
+    def test_create_instance_type_m_job(self, asset_upload_mock, path_is_dir_mock,
+                                   path_exists_mock, job_create_mock, is_logged_in_mock):
+        """
+        Successful path for creating a job using cluster instance type m
+        """
+        self._create_instance_type_job(asset_upload_mock, path_is_dir_mock,
+                                   path_exists_mock, job_create_mock, is_logged_in_mock, 'm')
+
+    @patch('disco.gql.authentication.Authentication.is_logged_in')
+    @patch('disco.Job.create')
+    @patch('pathlib.Path.exists')
+    @patch('pathlib.Path.is_dir')
+    @patch('disco.asset.Asset.upload')
+    def test_create_instance_type_l_job(self, asset_upload_mock, path_is_dir_mock,
+                                   path_exists_mock, job_create_mock, is_logged_in_mock):
+        """
+        Successful path for creating a job using cluster instance type l
+        """
+        self._create_instance_type_job(asset_upload_mock, path_is_dir_mock,
+                                   path_exists_mock, job_create_mock, is_logged_in_mock, 'l')
+
+    @patch('disco.gql.authentication.Authentication.is_logged_in')
+    @patch('disco.Job.create')
+    @patch('pathlib.Path.exists')
+    @patch('pathlib.Path.is_dir')
+    @patch('disco.asset.Asset.upload')
+    def test_create_instance_type_gpu_s_job(self, asset_upload_mock, path_is_dir_mock,
+                                   path_exists_mock, job_create_mock, is_logged_in_mock):
+        """
+        Successful path for creating a job using cluster instance type gpu_s
+        """
+        self._create_instance_type_job(asset_upload_mock, path_is_dir_mock,
+                                   path_exists_mock, job_create_mock, is_logged_in_mock, 'gpu_s')
+
+    @patch('disco.gql.authentication.Authentication.is_logged_in')
+    @patch('disco.Job.create')
+    @patch('pathlib.Path.exists')
+    @patch('pathlib.Path.is_dir')
+    @patch('disco.asset.Asset.upload')
+    def test_create_instance_type_gpu_m_job(self, asset_upload_mock, path_is_dir_mock,
+                                   path_exists_mock, job_create_mock, is_logged_in_mock):
+        """
+        Successful path for creating a job using cluster instance type gpu_m
+        """
+        self._create_instance_type_job(asset_upload_mock, path_is_dir_mock,
+                                   path_exists_mock, job_create_mock, is_logged_in_mock, 'gpu_m')
+
+    @patch('disco.gql.authentication.Authentication.is_logged_in')
+    @patch('disco.Job.create')
+    @patch('pathlib.Path.exists')
+    @patch('pathlib.Path.is_dir')
+    @patch('disco.asset.Asset.upload')
+    def test_create_instance_type_gpu_l_job(self, asset_upload_mock, path_is_dir_mock,
+                                   path_exists_mock, job_create_mock, is_logged_in_mock):
+        """
+        Successful path for creating a job using cluster instance type gpu_l
+        """
+        self._create_instance_type_job(asset_upload_mock, path_is_dir_mock,
+                                   path_exists_mock, job_create_mock, is_logged_in_mock, 'gpu_l')
+
+    def _create_instance_type_job(self, asset_upload_mock, path_is_dir_mock,
+                                  path_exists_mock, job_create_mock, is_logged_in_mock, instance_type):
+        is_logged_in_mock.return_value = True
+        path_exists_mock.return_value = True
+        path_is_dir_mock.return_value = False
+        job_create_mock.return_value = Job("job_id")
+        asset_upload_mock.return_value = 'file_id'
+        runner = CliRunner()
+        with runner.isolated_filesystem():
+            with open('script_file.py', 'w') as f:
+                f.write("print('hi!')")
+                result = runner.invoke(cli, f"job create -n job_name -s script_file.py -cit {instance_type}".split(' '))
+                assert result.exit_code == 0
+                assert output_message_includes(result, 'Created job with id job_id')
+                job_create_mock.assert_called_with(script_file_id='file_id', input_file_ids=[],
+                                                   constants_file_ids=[], job_name='job_name', cluster_instance_type=instance_type,
+                                                   cluster_id=None, instance_cost=None, script_repo_id=None, script_file_path_in_repo=None,
+                                                   auto_start=False, upload_requirements_file=True, docker_image_id=None
+                                                   )
+
+
     @patch('disco.gql.authentication.Authentication.is_logged_in')
     @patch('disco.Job.start')
     def test_start_job(self, job_start_mock, is_logged_in_mock):
